@@ -54,7 +54,7 @@
 
 /* Maximum zoom factor */
 
-#define MAX_ZOOM_FACTOR 128
+#define MAX_ZOOM_FACTOR 20
 #define MIN_ZOOM_FACTOR 0.01
 
 /* Private part of the ImageView structure */
@@ -427,7 +427,8 @@ image_view_destroy (GtkObject *object)
 
 	/* Clean up */
 	if (view->priv->pixbuf)
-		gdk_pixbuf_unref (view->priv->pixbuf);
+		g_object_unref (G_OBJECT (view->priv->pixbuf));
+	view->priv->pixbuf = NULL;
 
 	remove_dirty_region (view);
 
