@@ -57,6 +57,9 @@ struct _EogWindowPrivate {
 	/* vbox */
 	GtkWidget           *box;
 
+	/* preference dialog, if available */
+	GtkWidget           *pref_dlg;
+
 	/* statusbar */
 	GtkWidget *statusbar;
 
@@ -101,22 +104,36 @@ raise_and_focus (GtkWidget *widget)
 	gtk_widget_grab_focus (widget);
 }
 
+static void
+preference_dlg_closed_cb (GtkWidget *dlg, gpointer data)
+{
+	EogWindow *window;
+
+	window = EOG_WINDOW (data);
+	window->priv->pref_dlg = NULL;
+}
+
 /* Settings/Preferences callback */
 static void
 verb_Preferences_cb (BonoboUIComponent *uic, gpointer user_data, const char *cname)
 {
 	EogWindow *window;
-	EogPreferences *preferences;
+	EogWindowPrivate *priv;
 
 	g_return_if_fail (user_data != NULL);
 	g_return_if_fail (EOG_IS_WINDOW (user_data));
 
 	window = EOG_WINDOW (user_data);
+	priv = window->priv;
 
-	preferences = eog_preferences_new (window);
+	if (priv->pref_dlg == NULL) {
+		priv->pref_dlg = eog_preferences_new (window);
+		gtk_signal_connect (GTK_OBJECT (priv->pref_dlg), "destroy", 
+				    GTK_SIGNAL_FUNC (preference_dlg_closed_cb),
+				    window);
+	}
 
-	if (preferences != NULL)
-		gnome_dialog_run_and_close (GNOME_DIALOG (preferences));
+	gtk_window_present (GTK_WINDOW (priv->pref_dlg));
 }
 
 static void
@@ -171,8 +188,15 @@ verb_HelpAbout_cb (BonoboUIComponent *uic, gpointer user_data, const char *cname
 		"Lutz Mueller",
 		NULL
 	};
+	const char *translator_credits;
 
 	if (!about) {
+		/* Translators should localize the following string
+		 * which will be displayed at the bottom of the about
+		 * box to give credit to the translator(s).
+		 */
+		translator_credits = _("Translator Credits");
+
 		about = gnome_about_new (
 			_("Eye of Gnome"),
 			VERSION,
@@ -180,7 +204,7 @@ verb_HelpAbout_cb (BonoboUIComponent *uic, gpointer user_data, const char *cname
 			_("The GNOME image viewing and cataloging program"),
 			authors,
 			NULL, /* char **documentors */
-			NULL, /* char *translators */
+			translator_credits,
 			NULL);
 		gtk_signal_connect (GTK_OBJECT (about), "destroy",
 				    GTK_SIGNAL_FUNC (gtk_widget_destroyed),
@@ -355,6 +379,8 @@ eog_window_init (EogWindow *window)
 	priv = g_new0 (EogWindowPrivate, 1);
 	window->priv = priv;
 
+	priv->pref_dlg = NULL;
+	
 	priv->client = gconf_client_get_default ();
 
 	gconf_client_add_dir (priv->client, "/apps/eog",
@@ -1021,6 +1047,8 @@ eog_window_open (EogWindow *window, const char *text_uri)
 	GnomeVFSResult result;
 	GnomeVFSFileInfo *info;
 	GnomeVFSURI *uri;
+	GtkWidget *dlg;
+	gchar *uri_str;
 
 	g_return_val_if_fail (window != NULL, FALSE);
 	g_return_val_if_fail (EOG_IS_WINDOW (window), FALSE);
@@ -1044,16 +1072,11 @@ eog_window_open (EogWindow *window, const char *text_uri)
 	control = CORBA_OBJECT_NIL;
 
 	/* get appropriate control */
-	if (info->type == GNOME_VFS_FILE_TYPE_REGULAR)
+	if (info->type == GNOME_VFS_FILE_TYPE_REGULAR) {
 		control = get_viewer_control (uri, info);
-	else if (info->type == GNOME_VFS_FILE_TYPE_DIRECTORY)
+	}
+	else if (info->type == GNOME_VFS_FILE_TYPE_DIRECTORY) {
 		control = get_collection_control (uri, info);
-	else {
-		gchar *str;
-		str = gnome_vfs_uri_to_string (uri, GNOME_VFS_URI_HIDE_NONE);
-		g_warning ("Couldn't handle: %s.\n", str);
-		g_free (str);
-		return FALSE;
 	}
 
 	if (control != CORBA_OBJECT_NIL) {
@@ -1061,6 +1084,26 @@ eog_window_open (EogWindow *window, const char *text_uri)
 		add_control_to_ui (window, control);
 		bonobo_object_release_unref (control, NULL);
 	}
+	else {
+		uri_str = gnome_vfs_uri_to_string (uri, GNOME_VFS_URI_HIDE_NONE);
+
+		/* FIXME: The error message should be more specific 
+		 *        (eg. "Unknown file format").
+		 */
+		dlg = gtk_message_dialog_new (GTK_WINDOW (window),
+					      GTK_DIALOG_DESTROY_WITH_PARENT,
+					      GTK_MESSAGE_ERROR,
+					      GTK_BUTTONS_CLOSE,
+					      _("Unable to open %s."),
+					      uri_str);
+
+		gtk_signal_connect_object (GTK_OBJECT (dlg), "response",
+					   GTK_SIGNAL_FUNC (gtk_widget_destroy),
+					   GTK_OBJECT (dlg));
+		gtk_widget_show (dlg);
+
+		g_free (uri_str);
+	}
 
 	/* clean up */
 	gnome_vfs_file_info_unref (info);
